@@ -35,7 +35,7 @@ gettext.textdomain( 'backintime' )
 
 class Config( configfile.ConfigFileWithProfiles ):
 	APP_NAME = 'Back In Time'
-	VERSION = '1.0.4'
+	VERSION = '1.0.6'
 	COPYRIGHT = 'Copyright (c) 2008-2009 Oprea Dan, Bart de Koning, Richard Bailey'
 	CONFIG_VERSION = 5
 
@@ -556,10 +556,18 @@ class Config( configfile.ConfigFileWithProfiles ):
 		self.set_profile_bool_value( 'snapshots.dont_remove_named_snapshots', value, profile_id )
 	
 	def get_smart_remove( self, profile_id = None ):
-		return self.get_profile_bool_value( 'snapshots.smart_remove', False, profile_id )
+		return ( self.get_profile_bool_value( 'snapshots.smart_remove', False, profile_id ),
+				 self.get_profile_int_value( 'snapshots.smart_remove.keep_all', 2, profile_id ),
+				 self.get_profile_int_value( 'snapshots.smart_remove.keep_one_per_day', 7, profile_id ),
+				 self.get_profile_int_value( 'snapshots.smart_remove.keep_one_per_week', 4, profile_id ),
+				 self.get_profile_int_value( 'snapshots.smart_remove.keep_one_per_month', 24, profile_id ) )
 
-	def set_smart_remove( self, value, profile_id = None ):
+	def set_smart_remove( self, value, keep_all, keep_one_per_day, keep_one_per_week, keep_one_per_month, profile_id = None ):
 		self.set_profile_bool_value( 'snapshots.smart_remove', value, profile_id )
+		self.set_profile_int_value( 'snapshots.smart_remove.keep_all', keep_all, profile_id )
+		self.set_profile_int_value( 'snapshots.smart_remove.keep_one_per_day', keep_one_per_day, profile_id )
+		self.set_profile_int_value( 'snapshots.smart_remove.keep_one_per_week', keep_one_per_week, profile_id )
+		self.set_profile_int_value( 'snapshots.smart_remove.keep_one_per_month', keep_one_per_month, profile_id )
 	
 	def is_notify_enabled( self, profile_id = None ):
 		return self.get_profile_bool_value( 'snapshots.notify.enabled', True, profile_id )
@@ -796,8 +804,11 @@ class Config( configfile.ConfigFileWithProfiles ):
 			elif self.MONTH == min_backup_mode:
 				cron_line = 'echo "{msg}\n0 ' + str(self.get_automatic_backup_time( profile_id ) / 100) + ' 1 * * {cmd}"'
 
-			if len( cron_line ) > 0:
-				cmd = "/usr/local/bin/backintime --profile \\\"%s\\\" --backup-job >/dev/null 2>&1" % profile_name
+			if len( cron_line ) > 0:	
+				profile=''
+				if '1' != profile_id:
+					profile = "--profile-id %s" % profile_id
+				cmd = "/usr/local/bin/backintime %s --backup-job >/dev/null 2>&1" % profile
 				if self.is_run_nice_from_cron_enabled( profile_id ):
 					cmd = 'nice -n 19 ' + cmd
 				cron_line = cron_line.replace( '{cmd}', cmd )
